C-------------------------------------------------------------------
C------- ALPHA QCD -------------------------------------
c Program to calculate alfa strong with nf flavours,
c as a function of lambda with 5 flavors.
c The value of alfa is matched at the thresholds q = mq.
c When invoked with nf < 0 it chooses nf as the number of
c flavors with mass less then q.
c
      function alfas(q2,xlam,nloop,inf)
      implicit real * 8 (a-h,o-z)
      data olam/0.d0/,pi/3.14159d0/
      data xmb/4.5d0/,xmc/1.5d0/
      integer nloop
      if(xlam.ne.olam) then
        olam = xlam
        b5  = (33-2*5)/pi/12
        b4  = (33-2*4)/pi/12
        b3  = (33-2*3)/pi/12
        if(nloop.eq.1) then
           bp5=0
           bp4=0
           bp3=0
        elseif(nloop.eq.2) then
           bp5 = (153 - 19*5) / pi / 2 / (33 - 2*5)
           bp4 = (153 - 19*4) / pi / 2 / (33 - 2*4)
           bp3 = (153 - 19*3) / pi / 2 / (33 - 2*3)
        endif 
        xlc = 2 * log(xmc/xlam)
        xlb = 2 * log(xmb/xlam)
        xllc = log(xlc)
        xllb = log(xlb)
        c45  =  1/( 1/(b5 * xlb) - xllb*bp5/(b5 * xlb)**2 )
     #        - 1/( 1/(b4 * xlb) - xllb*bp4/(b4 * xlb)**2 )
        c35  =  1/( 1/(b4 * xlc) - xllc*bp4/(b4 * xlc)**2 )
     #        - 1/( 1/(b3 * xlc) - xllc*bp3/(b3 * xlc)**2 ) + c45
      endif
      q   = sqrt(q2)
      xlq = 2 * log( q/xlam )
      xllq = log( xlq )
      nf = inf
      if( nf .lt. 0) then
        if( q .gt. xmb ) then
          nf = 5
        elseif( q .gt. xmc ) then
          nf = 4
        else
          nf = 3
        endif
      endif
      if    ( nf .eq. 5 ) then
        alfas = 1/(b5 * xlq) -  bp5/(b5 * xlq)**2 * xllq
      elseif( nf .eq. 4 ) then
        alfas = 1/( 1/(1/(b4 * xlq) - bp4/(b4 * xlq)**2 * xllq) + c45 )
      elseif( nf .eq. 3 ) then
        alfas = 1/( 1/(1/(b3 * xlq) - bp3/(b3 * xlq)**2 * xllq) + c35 )
      else
        print *,'error in alfa: unimplemented # of light flavours',nf
        stop
      endif
      return
      end
c-------------------------------------------
c Program to calculate as with nf flavours
c as a function of lambda with nf flavours
c
      function alfa(q,xlam,nloop,nf)
      data pi/3.14159/
      xlp = float(nloop-1)
      b  = (33-2*nf)/pi/12
      bp = (153 - 19*nf) / pi / 2 / (33 - 2*nf)  * xlp
      t = 2 * log( q/xlam )
      xlt = log( t )
      alfa = 1/(b * t) -  bp/(b * t)**2 * xlt
      return
      end

c----------------------------------------------------------
c Program to get lambda_nf from as_nf at the scale q
c
      function xlambd(as,q,nloop,nf)
      implicit real * 8 (a-h,o-z)
      data pi/3.14159d0/
      xlp = float(nloop-1)
      b  = (33-2*nf)/pi/12
      bp = (153 - 19*nf) / pi / 2 / (33 - 2*nf) * xlp
      t  = 1/b/as
c-----------------------------------------------------------
c Solve the equation
c
    1 xlt = log(t)
      ot = t
c-----------------------------------------------------------
c Solve the equation
c Value and Derivative of alfa with respect to t
c
      as0  = 1/b/t - bp*xlt/(b*t)**2
      as1  = - 1/b/t**2 -bp/b**2*(1-2*xlt)/t**3
      t  = (as-as0)/as1 + t
      if(abs(ot-t)/ot.gt..00001)goto 1
      xlambd = q/exp(t/2)
      return
      end


      SUBROUTINE MWARN(ROUT)
      CHARACTER*(*) ROUT
      WRITE(*,*) '***********************************************'
      WRITE(*,*) '***** WARNING CALLED FROM ROUTINE ',ROUT,':'
      END


